import ContentEditorPage from './pages/ContentEditor/ContentEditorPage.js'

const ContentManagement = portlet => portlet
    .setName('Content')
    .setPriority(2)
    .setNavOrder(0)
    .setPermission('dynamic_content.content.get')
    .addPage('Content Editor', ContentEditorPage, { permission: 'dynamic_content.content.get' })

export default ContentManagement
