import ContentEditor from './components/ContentEditor/ContentEditor.vue.js'

const ContentEditorPage = page => {
  return page
    .setName('Content Editor')
    .setTitle('Content Management')
    .setSubtitle('Browse, edit, and publish content source files')
    .addComponent(ContentEditor, {})
}

export default ContentEditorPage
